#This script produces all the jpegs for Figure 4 and 5.
rm(list = ls(all.names = TRUE))

#Step 1. Loading libraries
install.packages("ggplot2")
install.packages("glue")
install.packages("gridExtra")
install.packages("grid")

library("ggplot2")
library("glue")
library("grid")
library("gridExtra")

#Step 2. Setting directory
#Mac or Windows
setwd("/Users/bgpopescu/Dropbox/Education Project/")
setwd("C:/Users/bogdanp/Dropbox/Education project/")
setwd("C:/Users/Popescu/Dropbox/Education project/")


#Step 3. In case it does not exist already, manually create a folder called "figures" in the Paper folder
#so that you can save the output from this script.

#Step 4. Reading Data
data<-read.csv(file="./Data/data_final.csv", header=TRUE, sep=",")

#Step 5. Selecting the data for the area of interest
data_final<-subset(data, agrozone==3)

#Step 6. Creating distances for RD analysis
data_final$dist1 <- as.numeric( with (data_final,ifelse(data_final$treat==1, 1, -1)))
data_final$dist2 <-data_final$dist1*data_final$core13_dist

#Step 7. Creating the Border Fixed Effects (BFEs)
data_final$bfe1 <- ifelse(data_final$core13_id == 1, 1,0)
data_final$bfe2 <- ifelse(data_final$core13_id == 2, 1,0)
data_final$bfe3 <- ifelse(data_final$core13_id == 3, 1,0)


####################
# Helper functions #
####################
comp_dist <- function(data_sample, y, x, spec, title_spec) {
  # Input:
  #   - data_sample, a dataframe with the relevant data
  #   - y, a string with the dependent variables
  #   - x, a list of strings with independent variables
  #   - spec, model specification
  #   - title_spec, label for the model specification (to appear on
  #                 the title of the graph)
  # Output:
  #   Creates one picture in the folder. This function
  #   compares bandwidths in increments of 1 Km for the outcomes
  #   of interest (y) and the specified model. 
  
  # Define range of potential bandwidths
  sequence = seq(from = 10, to = 85, by = 1)
  
  #Create empty variables
  confint1 = rep(NA, length(sequence))
  confint2 = rep(NA, length(sequence))
  confint3 = rep(NA, length(sequence))
  confint4 = rep(NA, length(sequence))
  coef1 = rep(NA, length(sequence))
  
  
  # This loop calculates local linear estimates
  # for bandwidths from 10 to 80 kilometers
  specification = as.formula(paste(glue("{y}~"), 
                                   paste(x, collapse = "+")))
  
  for (i in 1 : length(sequence)){
    band = data_sample[which(data_sample$dist2 > -sequence[i] & 
                               data_sample$dist2 < sequence[i]),]
    model1 <- lm(specification, data = band)
    confint1[i] = confint(model1)[2,1]
    confint2[i] = confint(model1)[2,2]
    confint3[i] = confint(model1, level = 0.90)[2,1]
    confint4[i] = confint(model1, level = 0.90)[2,2]  
    coef1[i] = coef(model1)[2]
  }
  
  df <- data.frame(sequence = sequence, coef1 = coef1, 
                   confint1 = confint1, confint2 = confint2,
                   confint3 = confint3, confint4 = confint4)
  
  mean_feature <- ggplot(data = df, aes(sequence, coef1)) +
    geom_point(size = 1.3) +
    geom_errorbar(aes(ymin = confint1, ymax = confint2), size = 0.2, width = 0)+
    geom_errorbar(aes(ymin = confint3, ymax = confint4), size = 0.5, width = 0)+
    geom_hline(yintercept = 0) +
    theme_bw() +
    scale_x_continuous(name = "Bandwidth (km)", limits = c(10, 85)) +
    scale_y_continuous(name = "Estimate") +
    ggtitle(glue("{title_spec}")) +
    theme(plot.title = element_text(hjust = 0.5),
          axis.text.x = element_text(size=14),
          axis.text.y = element_text(size=14),
          axis.title=element_text(size=14))+
    annotate(geom = "text", -Inf, Inf, label = c(paste("Treatment:", nrow(data_sample[data_sample$treat==1,]), "\n", 
                                                       "Control:", nrow(data_sample[data_sample$treat==0,]))), hjust = 0, vjust = 1)

  return(mean_feature)
}

create_graphs_per_specifications <- function(regressors, specifications, 
                                             specification_label, data_sample){
  # Input:
  #   - regressors, a list of dependent variables
  #   - specifications, lists of model specifications (indep variables)
  #   - specification_label, a list of labels for model specifications
  #   - data_sample, the dataset of interest
  #   - data_sample_name, label for the data_sample
  
  # Output:
  #   Creates one grid of pictures in the folder. This function
  #   allows us to vary the regressors.
  
  for (y in regressors) {
    regressor_name  = y[[1]]
    regressor_label = y[[2]]
    figure_no = y[[3]]
    
    print(glue("Using dependent variable {regressor_label}.."))
    graphs <- list()
    for (spec in names(specifications)){
      print(spec)
      print(specification_label[[spec]])
      temp_graph <- comp_dist(data_sample, regressor_name, 
                              specifications[[spec]], spec, 
                              specification_label[[spec]])
      graphs[[paste(c(spec, regressor_name), collapse = '_')]] <- temp_graph
    }
    
    #Ncol may need to be changed
    grid <- grid.arrange(grobs = graphs, nrow = 1, ncol = 3,
                         top = textGrob({regressor_label},
                                        gp = gpar(fontsize = 20, font = 2)))
    ggsave(grid, file = glue("Figure {figure_no}.jpg"), 
           height = 10, width = 50, 
           units = "cm", dpi = 300)
  }
  
}




########
#MODELS#
########


specifications <- list(c('treat'),
                       c('treat', 'core13_dist'),
                       c('treat', 'core13_dist', 'bfe1', 'bfe2', 'bfe3'))

names(specifications) <- c('mean', 'onlydist', "onlydistbfe")
specification_label<-c('Treatment', "Treatment + Distance", "Treatment + Distance + FE")
names(specification_label)<-c('mean', 'onlydist', "onlydistbfe")


regressors<-list(c("pagri61T", "Economically Active Population in Agriculture", "4a"),
                 c("chozas_viviendasrural1961", "Rural Poverty", "4b"),
                 c("Prur_M50", "Rural Population Living in Haciendas", "4c"),
                 c("elev", "Elevation", "5a"), 
                 c("slope", "Slope", "5b"),
                 c("icult_land_maj", "Cultivated Land", "5c"),
                 c("total_road_1973", 'Road Density',  '5d'),
                 c("pop1972_sup_ha",  "Population Density", "5e"),
                 c("cotton_intinput_irrigated", "Attainable Cotton Yield", "5f"),
                 c("sugarcane_intinput_irrigated", "Attainable Sugarcane Yield", "5g"))


shortcut = glue("./Paper/figures")
setwd(shortcut)



create_graphs_per_specifications(regressors, specifications, 
                                   specification_label, data_final)


